<?php

namespace Litecms\Place\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litecms\Place\Interfaces\CityRepositoryInterface;

class CityPublicController extends BaseController
{
    // use CityWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litecms\City\Interfaces\CityRepositoryInterface $city
     *
     * @return type
     */
    public function __construct(CityRepositoryInterface $city)
    {
        $this->repository = $city;
        parent::__construct();
    }

    /**
     * Show city's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $cities = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$place::$city.names'))
            ->view('$place::public.city.index')
            ->data(compact('$cities'))
            ->output();
    }

    /**
     * Show city's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $cities = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$place::$city.names'))
            ->view('$place::public.city.index')
            ->data(compact('$cities'))
            ->output();
    }

    /**
     * Show city.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $city = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$city->name . trans('$place::$city.name'))
            ->view('$place::public.city.show')
            ->data(compact('$city'))
            ->output();
    }

}
